import { Suspense } from "react";


import { AboutLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import RelatedProjectsClient from "@/components/sections/projects/related-projects";
import ProjectDetails from "@/components/shared/project-info-client";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import LocomotiveScrollWrapper from "@/components/ui/locomotive-scroll-wrapper";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { fetchProjectById } from "@/servers/actions/project-action";
import { Icon } from "@iconify/react/dist/iconify.js";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";
import { useLocale, useTranslations } from "next-intl";
import { getLocale } from "next-intl/server";




export default async function ProjectDetailsPage({
	params,
}: {
	params: Promise<{ id: any }>;
}) {
	const { id } = await params;
	const locale = await getLocale() as Locale;


	/*const parsedParams = await paramSchema.safeParse(id);

	if (!parsedParams.success) {
		return notFound();
	}*/

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/projects",
			label: {
				en: "Projects",
				ar: "المشاريع",
			},
		}
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({ queryKey: ["project"], queryFn: () => fetchProjectById(id) }),

	]);

	const _data = queryClient.getQueryData<any>(["project"]);
	console.log("_data: ", _data);
	const _project = _data?.data;
	console.log("project: ", _project);

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<LocomotiveScrollWrapper>
				<main className="block">
					<Header />
					<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
						<PageBreadcrump
							locale={locale}
							subtitle={{
								en: "Company Projects",
								ar: "مشاريع الشركة",
							}}
							title={{
								en: _project?.title_en,
								ar: _project?.title_ar,
							}}
							breadcrumbItems={breadcrumbItems}
							backgroundUrl="/project.png"
						/>
						<div className="px-2 sm:px-2 md:px-4 lg:px-4 xl:px-14">
							<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
								<ProjectVideo _project={_project} />
								<ProjectDetails _project={_project} />
								<hr />
								<RelatedProjectsClient />
							</Suspense>
						</div>
						<Footer />
					</Suspense>
				</main>
			</LocomotiveScrollWrapper>
		</HydrationBoundary>
	);
}

const ProjectVideo = ({ _project }: { _project: any }) => {
	const t = useTranslations();
	const locale = useLocale();

	return (
		<>
			<div className="relative mx-auto w-3/4 h-96 my-8">
				<video
					src={ImageBaseUrl + _project?.video}
					className="h-full w-full rounded-md"
					controls
					autoPlay
				/>
			</div>
			<div className="flex flex-row justify-between mt-4">
				<div className="text-md text-custom-primary-accent flex flex-row items-center gap-2">
					<Icon icon="mdi:map-marker" className="w-6 h-6" />
					{t("project location")}: {locale === "ar" ? _project?.city_ar : _project?.city_en}
				</div>
				<div className="text-md text-custom-primary-accent flex flex-row items-center gap-2">
					<Icon icon="mdi:calendar" className="w-6 h-6" />
					{t("project date")}: {_project?.date}
				</div>
			</div>
			<hr className="my-4" />
		</>
	);
};



